==> apache-asterixdb-0.9.1-source-release.zip: apache-asterixdb-0.9.1/asterix-common/src/main/java/org/apache/asterix/common/replication/IFaultToleranceStrategy.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.asterix.common.replication;

import org.apache.asterix.common.cluster.IClusterStateManager;
import org.apache.asterix.common.messaging.api.ICCMessageBroker;
import org.apache.hyracks.api.exceptions.HyracksDataException;

public interface IFaultToleranceStrategy {

    /**
     * Defines the logic of a {@link IFaultToleranceStrategy} when a node joins the cluster.
     *
     * @param nodeId
     * @throws HyracksDataException
     */
    void notifyNodeJoin(String nodeId) throws HyracksDataException;

    /**
     * Defines the logic of a {@link IFaultToleranceStrategy} when a node leaves the cluster.
     *
     * @param nodeId
     * @throws HyracksDataException
     */
    void notifyNodeFailure(String nodeId) throws HyracksDataException;

    /**
     * Binds the fault tolerance strategy to {@code cluserManager}.
     *
     * @param clusterManager
     */
    void bindTo(IClusterStateManager clusterManager);

    /**
     * Processes {@code message} based on the message type.
     *
     * @param message
     * @throws HyracksDataException
     */
    void process(INCLifecycleMessage message) throws HyracksDataException;

    /**
     * Constructs a fault tolerance strategy.
     *
     * @param replicationStrategy
     * @param messageBroker
     * @return
     */
    IFaultToleranceStrategy from(IReplicationStrategy replicationStrategy, ICCMessageBroker messageBroker);

}

==> apache-asterixdb-0.9.2-source-release.zip: apache-asterixdb-0.9.2/asterix-common/src/main/java/org/apache/asterix/common/replication/IFaultToleranceStrategy.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.asterix.common.replication;

import org.apache.asterix.common.cluster.IClusterStateManager;
import org.apache.hyracks.api.application.ICCServiceContext;
import org.apache.hyracks.api.exceptions.HyracksDataException;

public interface IFaultToleranceStrategy {

    /**
     * Defines the logic of a {@link IFaultToleranceStrategy} when a node joins the cluster.
     *
     * @param nodeId
     * @throws HyracksDataException
     */
    void notifyNodeJoin(String nodeId) throws HyracksDataException;

    /**
     * Defines the logic of a {@link IFaultToleranceStrategy} when a node leaves the cluster.
     *
     * @param nodeId
     * @throws HyracksDataException
     */
    void notifyNodeFailure(String nodeId) throws HyracksDataException;

    /**
     * Binds the fault tolerance strategy to {@code cluserManager}.
     *
     * @param clusterManager
     */
    void bindTo(IClusterStateManager clusterManager);

    /**
     * Processes {@code message} based on the message type.
     *
     * @param message
     * @throws HyracksDataException
     */
    void process(INCLifecycleMessage message) throws HyracksDataException;

    /**
     * Constructs a fault tolerance strategy.
     *
     * @param replicationStrategy
     * @param messageBroker
     * @return
     */
    IFaultToleranceStrategy from(ICCServiceContext serviceCtx, IReplicationStrategy replicationStrategy);

}
